@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ObjectStorageServerProtocolType, S3StorageClassType
 from .paginator import (
@@ -85,24 +85,33 @@ class Exceptions:
     InvalidRequestException: Type[BotocoreClientError]
 
 
-class DataSyncClient:
+class DataSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        DataSyncClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#can_paginate)
         """
 
     def cancel_task_execution(self, *, TaskExecutionArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        Cancels execution of a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#cancel_task_execution)
         """
 
@@ -117,7 +126,9 @@ class DataSyncClient:
         SecurityGroupArns: List[str] = None
     ) -> CreateAgentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_agent)
+        Activates an AWS DataSync agent that you have deployed on your host.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_agent)
         """
 
@@ -130,7 +141,9 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateLocationEfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        Creates an endpoint for an Amazon EFS file system.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_efs)
         """
 
@@ -146,7 +159,9 @@ class DataSyncClient:
         Domain: str = None
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        Creates an endpoint for an Amazon FSx for Windows File Server file system.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_fsx_windows)
         """
 
@@ -160,7 +175,10 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateLocationNfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        Defines a file system on a Network File System (NFS) server that can be read
+        from or written to.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_nfs)
         """
 
@@ -178,7 +196,9 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        Creates an endpoint for a self-managed object storage bucket.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_object_storage)
         """
 
@@ -193,7 +213,9 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateLocationS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        Creates an endpoint for an Amazon S3 bucket.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_s3)
         """
 
@@ -210,7 +232,10 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateLocationSmbResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        Defines a file system on a Server Message Block (SMB) server that can be read
+        from or written to.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_smb)
         """
 
@@ -227,37 +252,50 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None
     ) -> CreateTaskResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.create_task)
+        Creates a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.create_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_task)
         """
 
     def delete_agent(self, *, AgentArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.delete_agent)
+        Deletes an agent.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.delete_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_agent)
         """
 
     def delete_location(self, *, LocationArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.delete_location)
+        Deletes the configuration of a location used by AWS DataSync.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.delete_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_location)
         """
 
     def delete_task(self, *, TaskArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.delete_task)
+        Deletes a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.delete_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_task)
         """
 
     def describe_agent(self, *, AgentArn: str) -> DescribeAgentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_agent)
+        Returns metadata such as the name, the network interfaces, and the status (that
+        is, whether the agent is running or not) for an agent.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_agent)
         """
 
     def describe_location_efs(self, *, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        Returns metadata, such as the path information about an Amazon EFS location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_efs)
         """
 
@@ -265,13 +303,18 @@ class DataSyncClient:
         self, *, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        Returns metadata, such as the path information about an Amazon FSx for Windows
+        File Server location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_fsx_windows)
         """
 
     def describe_location_nfs(self, *, LocationArn: str) -> DescribeLocationNfsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        Returns metadata, such as the path information, about an NFS location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_nfs)
         """
 
@@ -279,25 +322,33 @@ class DataSyncClient:
         self, *, LocationArn: str
     ) -> DescribeLocationObjectStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        Returns metadata about a self-managed object storage server location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_object_storage)
         """
 
     def describe_location_s3(self, *, LocationArn: str) -> DescribeLocationS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        Returns metadata, such as bucket name, about an Amazon S3 bucket location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_s3)
         """
 
     def describe_location_smb(self, *, LocationArn: str) -> DescribeLocationSmbResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        Returns metadata, such as the path and user information about an SMB location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_smb)
         """
 
     def describe_task(self, *, TaskArn: str) -> DescribeTaskResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_task)
+        Returns metadata about a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task)
         """
 
@@ -305,7 +356,9 @@ class DataSyncClient:
         self, *, TaskExecutionArn: str
     ) -> DescribeTaskExecutionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        Returns detailed metadata about a task that is being executed.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task_execution)
         """
 
@@ -317,7 +370,9 @@ class DataSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#generate_presigned_url)
         """
 
@@ -325,7 +380,10 @@ class DataSyncClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListAgentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.list_agents)
+        Returns a list of agents owned by an AWS account in the AWS Region specified in
+        the request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.list_agents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_agents)
         """
 
@@ -334,10 +392,12 @@ class DataSyncClient:
         *,
         MaxResults: int = None,
         NextToken: str = None,
-        Filters: List[LocationFilterTypeDef] = None
+        Filters: List["LocationFilterTypeDef"] = None
     ) -> ListLocationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.list_locations)
+        Returns a list of source and destination locations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.list_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_locations)
         """
 
@@ -345,7 +405,9 @@ class DataSyncClient:
         self, *, ResourceArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        Returns all the tags associated with a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tags_for_resource)
         """
 
@@ -353,7 +415,9 @@ class DataSyncClient:
         self, *, TaskArn: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListTaskExecutionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        Returns a list of executed tasks.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.list_task_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_task_executions)
         """
 
@@ -362,10 +426,12 @@ class DataSyncClient:
         *,
         MaxResults: int = None,
         NextToken: str = None,
-        Filters: List[TaskFilterTypeDef] = None
+        Filters: List["TaskFilterTypeDef"] = None
     ) -> ListTasksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.list_tasks)
+        Returns a list of all the tasks.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.list_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tasks)
         """
 
@@ -377,7 +443,9 @@ class DataSyncClient:
         Includes: List["FilterRuleTypeDef"] = None
     ) -> StartTaskExecutionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        Starts a specific invocation of a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.start_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#start_task_execution)
         """
 
@@ -385,19 +453,25 @@ class DataSyncClient:
         self, *, ResourceArn: str, Tags: List["TagListEntryTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.tag_resource)
+        Applies a key-value pair to an AWS resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.untag_resource)
+        Removes a tag from an AWS resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#untag_resource)
         """
 
     def update_agent(self, *, AgentArn: str, Name: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_agent)
+        Updates the name of an agent.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_agent)
         """
 
@@ -410,7 +484,10 @@ class DataSyncClient:
         MountOptions: "NfsMountOptionsTypeDef" = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        Updates some of the parameters of a previously created location for Network File
+        System (NFS) access.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_nfs)
         """
 
@@ -426,7 +503,10 @@ class DataSyncClient:
         AgentArns: List[str] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        Updates some of the parameters of a previously created location for self-managed
+        object storage server access.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_object_storage)
         """
 
@@ -442,7 +522,10 @@ class DataSyncClient:
         MountOptions: "SmbMountOptionsTypeDef" = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        Updates some of the parameters of a previously created location for Server
+        Message Block (SMB) file system access.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_smb)
         """
 
@@ -457,7 +540,9 @@ class DataSyncClient:
         CloudWatchLogGroupArn: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_task)
+        Updates the metadata associated with a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task)
         """
 
@@ -465,20 +550,24 @@ class DataSyncClient:
         self, *, TaskExecutionArn: str, Options: "OptionsTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        Updates execution of a task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Client.update_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Paginator.ListAgents)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Paginator.ListLocations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
         """
 
     @overload
@@ -486,7 +575,8 @@ class DataSyncClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
         """
 
     @overload
@@ -494,11 +584,13 @@ class DataSyncClient:
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/datasync.html#DataSync.Paginator.ListTasks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
         """
